=================
OpenStack Vitrage
=================

.. image:: https://governance.openstack.org/tc/badges/vitrage.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

OpenStack Vitrage is the OpenStack RCA (Root Cause Analysis) Service for organizing, analyzing and expanding OpenStack alarms & events, yielding insights regarding the root cause of problems and deducing the existence of problems before they are directly detected.

Enabling Vitrage in DevStack
----------------------------
More details in: `README file <devstack/README.rst>`_

Project Resources
-----------------

* Project documentation: https://docs.openstack.org/vitrage/latest/
* Wiki page: https://wiki.openstack.org/wiki/Vitrage
* Source: https://opendev.org/openstack/vitrage
* StoryBoard: https://storyboard.openstack.org/#!/project/openstack/vitrage
* Release notes: https://docs.openstack.org/releasenotes/vitrage
* Design specifications: https://specs.openstack.org/openstack/vitrage-specs/
